
clear all
clf

fpath = '..\runs\Bump_V2\';
fname = 'Flow_Bump';

%% Measured
zm = load('..\data\bump_analytical_wse.txt');
hm = load('..\data\bump_depth.txt');
xm = zm(:,1);
ym = zm(:,2);

%% Grid 
grd = readcmsgrd([fpath,'Implicit\',fname,'_grid.h5']);
xc = grd.x;
nx = grd.nx;
yc = grd.depth(1:nx);

%% Implicit 
zcc = load('..\data\bump_calc_wse.txt');
hcc = load('..\data\bump_calc_depth.txt');
xcc = hcc(:,1);
hcc = hcc(:,2);
zcc = zcc(:,2);
sol = readcmssol([fpath,'Implicit\Run2\',fname,'_sol.h5']);
zcc = sol.Water_Elevation.Values(:,end-3);
zcc = zcc(1:nx);
xcc = xc;

%% Explicit
sol = readcmssol([fpath,'Explicit\',fname,'_sol.h5']);
zc = sol.Flow_Bump_elev.Values(:,end-3);
zc = zc(1:nx);

zm = [5 zm(1,2); zm; 15 zm(end,2)];

%% Plotting
set(gcf,'position',[524   342   543   302])
set(gca,'box','on','nextplot','add')
%plot(xc,0.33-yc,'k-','linewidth',2) %bed
hh=fill(xc,0.33-yc,'k','facecolor',0.8*[1 1 1],'linewidth',2); %bed
plot(xm,ym,'-','linewidth',2)       %analytical
plot(xcc,zcc+0.33,'ok','markerfacecolor','r','markersize',4)   %implicit
plot(xc,zc+0.33,'sk','markerfacecolor','g','markersize',4)    %explicit
set(gca,'xlim',[5,15],'ylim',[0 0.45])
xlabel('Distance, m')
ylabel('Elevation, m')
legend('Bed','WSE - Analytical','WSE - Implicit','WSE - Explicit',0)


return
%% Statistics (on analytical solution points)
yci = interp1(xc,hc+0.33,xm);
range(1) = max(ym)-min(ym);
rmse(1) = sqrt(mean((yci-ym).^2));
nrmse(1) = rmse/range;
mae(1) = mean(abs(yci-ym));
nmae(1) = mae/range;
R = corrcoef(yci,ym);
R2(1) = R(1,2).^2;
B(1) = mean(yci-ym);
NB(1) = B/range;

yci = interp1(zcc(:,1),zcc(:,2)+0.33,xm);
range(2) = max(ym)-min(ym);
rmse(2) = sqrt(mean((yci-ym).^2));
nrmse(2) = rmse/range;
mae(2) = mean(abs(yci-ym));
nmae(2) = mae/range;
R = corrcoef(yci,ym);
R2(2) = R(1,2).^2;
B(2) = mean(yci-ym);
NB(2) = B/range;

return





xc = zc(:,1);
yc = zc(:,2)+0.33;

zm = [5 zm(1,2); zm; 15 zm(end,2)];
plot(zm(:,1),zm(:,2),'-',xc,yc,'or',...
    hc(:,1),-hc(:,2)+0.33,'k-','linewidth',2)
set(gca,'xlim',[5,15],'ylim',[0 0.45])
xlabel('Distance, m')
ylabel('Elevation, m')
legend('WSE - Analytical','WSE - Calculated','Bed')

%Statistics (on analytical solution points)
yc=interp1(xc,yc,xm);
rmse = sqrt(mean((yc-ym).^2));
rmae = abs(mean((yc-ym)))/(max(ym)-min(ym));
R = corrcoef(yc,ym);
R2 = R(1,2).^2;
B = mean(ym) - mean(yc);

figure
plot(ym,yc,'.')

return

